==> forms-v5.2.1.tar.gz: forms/l10n/ka.js <==
OC.L10N.register(
    "forms",
    {
    "No" : "No",
    "Yes" : "Yes",
    "Question" : "Question",
    "Copy" : "Copy",
    "Shared with you" : "Shared with you",
    "Select groups" : "Select groups",
    "Results" : "შედეგი",
    "Cancel" : "Cancel",
    "Go to previous page" : "Go to previous page",
    "Delete" : "Delete",
    "Uploading …" : "Uploading …",
    "Other" : "Other",
    "never" : "never",
    "Set expiration date" : "Set expiration date",
    "Group" : "Group",
    "Permissions" : "Permissions",
    "Share link" : "Share link",
    "Copy to clipboard" : "Copy to clipboard",
    "Copy embedding code" : "Copy embedding code",
    "Internal link" : "Internal link",
    "View" : "View",
    "Edit" : "Edit",
    "Share" : "Share",
    "Description" : "Description",
    "Summary" : "Summary",
    "Download" : "Download",
    "Search" : "ძიება",
    "No results found" : "No results found",
    "Sharing" : "Sharing",
    "Settings" : "Settings",
    "Abort" : "Abort",
    "Submit" : "Submit",
    "Clear" : "Clear",
    "Cannot copy, please copy the link manually" : "Cannot copy, please copy the link manually",
    "No recommendations. Start typing." : "No recommendations. Start typing.",
    "No elements found." : "No elements found.",
    "Checkboxes" : "Checkboxes",
    "File" : "File",
    "Date" : "Date",
    "Pick a date" : "Pick a date",
    "Time" : "Time",
    "Pick a time" : "Pick a time",
    "Color" : "Color",
    "Image" : "Image",
    "Presentation" : "Presentation",
    "Text" : "Text",
    "Phone number" : "Phone number",
    "Email address" : "Email address"
},
"nplurals=2; plural=(n!=1);");

==> forms-v5.2.3.tar.gz: forms/l10n/ka.js <==
OC.L10N.register(
    "forms",
    {
    "No" : "No",
    "Yes" : "Yes",
    "Question" : "Question",
    "Copy" : "Copy",
    "Shared with you" : "Shared with you",
    "Select groups" : "Select groups",
    "Results" : "შედეგი",
    "Cancel" : "Cancel",
    "Go to previous page" : "Go to previous page",
    "Delete" : "Delete",
    "Other" : "Other",
    "never" : "never",
    "Set expiration date" : "Set expiration date",
    "Group" : "Group",
    "Permissions" : "Permissions",
    "Share link" : "Share link",
    "Copy to clipboard" : "Copy to clipboard",
    "Copy embedding code" : "Copy embedding code",
    "Internal link" : "Internal link",
    "View" : "View",
    "Edit" : "Edit",
    "Share" : "Share",
    "Description" : "Description",
    "Summary" : "Summary",
    "Download" : "Download",
    "Search" : "ძიება",
    "No results found" : "No results found",
    "Sharing" : "Sharing",
    "Settings" : "Settings",
    "Abort" : "Abort",
    "Submit" : "Submit",
    "Clear" : "Clear",
    "Cannot copy, please copy the link manually" : "Cannot copy, please copy the link manually",
    "No recommendations. Start typing." : "No recommendations. Start typing.",
    "No elements found." : "No elements found.",
    "Checkboxes" : "Checkboxes",
    "File" : "File",
    "Date" : "Date",
    "Pick a date" : "Pick a date",
    "Time" : "Time",
    "Pick a time" : "Pick a time",
    "Color" : "Color",
    "Image" : "Image",
    "Presentation" : "Presentation",
    "Text" : "Text",
    "Phone number" : "Phone number",
    "Email address" : "Email address",
    "Uploading …" : "Uploading …"
},
"nplurals=2; plural=(n!=1);");
